@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 import os
-from logging import getLogger
 import warnings
+from logging import getLogger
 
 import questionary
 
@@ -23,7 +23,7 @@ from commitizen.exceptions import (
     NoVersionSpecifiedError,
 )
 from commitizen.providers import get_provider
-from commitizen.version_schemes import get_version_scheme, InvalidVersion
+from commitizen.version_schemes import InvalidVersion, get_version_scheme
 
 logger = getLogger("commitizen")
 
@@ -36,6 +36,7 @@ class Bump:
             raise NotAGitProjectError()
 
         self.config: BaseConfig = config
+        self.encoding = config.settings["encoding"]
         self.arguments: dict = arguments
         self.bump_settings: dict = {
             **config.settings,
@@ -298,6 +299,7 @@ class Bump:
             str(new_version),
             version_files,
             check_consistency=self.check_consistency,
+            encoding=self.encoding,
         )
 
         provider.set_version(str(new_version))
